@@ -1,5 +1,6 @@
-#include "RcppArmadillo.h"
+#include <RcppArmadillo.h>
 #include "misc.h"
+#include "setdiff.h"
 
 // [[Rcpp::depends(RcppArmadillo)]]
 //' @title Correction Kernel
@@ -24,7 +25,7 @@ Rcpp::List correction_kernel(
   const int n_items
 ) {
   // check if new information means 'mistakes' made with augmented rankings
-  const bool observed_equals_current = arma::approx_equal(\
+  const bool observed_equals_current = approx_equal(\
     observed_ranking, current_ranking, "absdiff", 0.1\
   );
   double correction_prob = 1.0;
@@ -35,7 +36,7 @@ Rcpp::List correction_kernel(
     // resample from smaller pool of possible augmented rankings
 
     //  find elements missing from original observed ranking
-    arma::vec remaining_set = arma_setdiff_vec(current_ranking, observed_ranking);
+    arma::vec remaining_set = setdiff_template(current_ranking, observed_ranking);
 
     // create new agumented ranking by sampling remaining ranks from set uniformly
     proposed_ranking = observed_ranking;
@@ -45,7 +46,7 @@ Rcpp::List correction_kernel(
       proposed_ranking.elem(unranked_items) = remaining_set;
     } else {
       // generate random order for remaining_set
-      remaining_set = std::move(arma::shuffle(remaining_set));
+      remaining_set = std::move(shuffle(remaining_set));
       proposed_ranking.elem(unranked_items) = remaining_set;
     }
     correction_prob = divide_by_fact(correction_prob, remaining_set.n_elem);
