@@ -1,7 +1,6 @@
 context("SMC uniform functions")
 
-  set.seed(101)
-require("BayesMallows")
+set.seed(101)
 
 # tests for M-H_aug_ranking function ===========================================
 
@@ -14,7 +13,7 @@ test_that("MH-aug ranking works", {
 
   # Three missing ranks ------------------------------------ #
   R_curr <- c(1, 2, 3, 6, 5, 4)
-  R_obs  <- c(1, 2, 3, NA, NA, NA)
+  R_obs <- c(1, 2, 3, NA, NA, NA)
   set.seed(584)
   test_1 <- metropolis_hastings_aug_ranking(
     current_ranking = R_curr,
@@ -22,7 +21,8 @@ test_that("MH-aug ranking works", {
     alpha           = alpha,
     rho             = rho,
     n_items         = n_items,
-    metric          = metric
+    metric          = metric,
+    pseudo = FALSE
   )
   expect_equal(test_1, as.matrix(c(1, 2, 3, 6, 5, 4)))
   expect_equal(get_rank_distance(rho, test_1, metric = "ulam"), 2)
@@ -33,7 +33,7 @@ test_that("MH-aug ranking works", {
   set.seed(866)
   test_2 <- metropolis_hastings_aug_ranking(
     current_ranking = R_curr, partial_ranking = R_obs, alpha = alpha,
-    rho = rho, n_items = n_items, metric = metric
+    rho = rho, n_items = n_items, metric = metric, pseudo = FALSE
   )
   expect_equal(test_2, as.matrix(c(1, 2, 3, 4, 5, 6)))
   expect_equal(all(test_2 == rho), TRUE)
@@ -45,7 +45,7 @@ test_that("MH-aug ranking works", {
   set.seed(545)
   test_3 <- metropolis_hastings_aug_ranking(
     current_ranking = R_curr, partial_ranking = R_obs, alpha = alpha,
-    rho = rho, n_items = n_items, metric = metric
+    rho = rho, n_items = n_items, metric = metric, pseudo = FALSE
   )
   expect_equal(test_3, as.matrix(c(1, 2, 3, 6, 5, 4)))
   expect_equal(all(test_3 == R_curr), TRUE)
@@ -61,16 +61,16 @@ test_that("correction_kernel works", {
   R_obs <- c(1, 2, 3, NA, NA, NA)
   set.seed(879)
   test_4 <- correction_kernel(R_obs, R_curr, n_items)
-  expect_equal(test_4$ranking, as.matrix(c(1, 2, 3, 6, 4, 5)))
+  expect_equal(test_4$ranking, as.matrix(c(1, 2, 3, 4, 5, 6)))
   expect_equal(test_4$correction_prob, 1 / 6)
-  expect_equal(all(test_4$ranking == R_curr), FALSE)
+  expect_equal(all(test_4$ranking == R_curr), TRUE)
 
   # Two missing ranks -------------------------------------- #
   R_curr <- c(1, 2, 3, 4, 5, 6)
   R_obs <- c(1, 2, 3, 5, NA, NA)
   set.seed(706)
   test_5 <- correction_kernel(R_obs, R_curr, n_items)
-  expect_equal(test_5$ranking, as.matrix(c(1, 2, 3, 5, 4, 6)))
+  expect_equal(test_5$ranking, as.matrix(c(1, 2, 3, 5, 6, 4)))
   expect_equal(test_5$correction_prob, 0.5)
   expect_equal(all(test_5$ranking == R_curr), FALSE)
 
